var zypp_core_2AutoDispose_8h =
[
    [ "zypp::AutoDispose< Tp >", "classzypp_1_1AutoDispose.html", "classzypp_1_1AutoDispose" ],
    [ "zypp::AutoDispose< Tp >::Impl", "structzypp_1_1AutoDispose_1_1Impl.html", "structzypp_1_1AutoDispose_1_1Impl" ],
    [ "zypp::AutoDispose< void >::Impl", "structzypp_1_1AutoDispose_3_01void_01_4_1_1Impl.html", "structzypp_1_1AutoDispose_3_01void_01_4_1_1Impl" ],
    [ "zypp::Deferred", "structzypp_1_1Deferred.html", "structzypp_1_1Deferred" ],
    [ "zypp::AutoFREE< Tp >", "structzypp_1_1AutoFREE.html", "structzypp_1_1AutoFREE" ],
    [ "zypp::AutoFREE< void >", "structzypp_1_1AutoFREE_3_01void_01_4.html", "structzypp_1_1AutoFREE_3_01void_01_4" ],
    [ "__zypp_defer_concatenate", "zypp-core_2AutoDispose_8h.html#ad69c622837e52d846d613d3ba97a0413", null ],
    [ "__zypp_defer_declarator", "zypp-core_2AutoDispose_8h.html#a5af0b29cd5fb9300cccbfc2d810646a1", null ],
    [ "zypp_defer", "zypp-core_2AutoDispose_8h.html#ac1603258205724b0a1bdeb21ecad03b7", null ],
    [ "zypp::OnScopeExit", "namespacezypp.html#ad3e543bfd966f168b14363299ba9a66f", null ]
];